rename var: authopts.Token -> authopts.TokenID
diff --git a/auth_options.go b/auth_options.go
index efa5961..d26e16a 100644
--- a/auth_options.go
+++ b/auth_options.go
@@ -44,7 +44,7 @@
 	// possible.  This setting defaults to false.
 	AllowReauth bool
 
-	// Token allows users to authenticate (possibly as another user) with an
-	// authentication token.
-	Token string
+	// TokenID allows users to authenticate (possibly as another user) with an
+	// authentication token ID.
+	TokenID string
 }